package javax.xml.bind;

import java.util.Calendar;
import javax.xml.namespace.QName;
import javax.xml.namespace.NamespaceContext;
import java.math.BigDecimal;
import java.math.BigInteger;

public final class DatatypeConverter
{
    private static volatile DatatypeConverterInterface theConverter;
    private static final JAXBPermission SET_DATATYPE_CONVERTER_PERMISSION;
    
    private DatatypeConverter() {
    }
    
    public static void setDatatypeConverter(DatatypeConverterInterface converter) {
        if (converter == null) {
            throw new IllegalArgumentException(Messages.format("DatatypeConverter.ConverterMustNotBeNull"));
        }
        if (DatatypeConverter.theConverter == null) {
            SecurityManager sm = System.getSecurityManager();
            if (sm != null) {
                sm.checkPermission(DatatypeConverter.SET_DATATYPE_CONVERTER_PERMISSION);
            }
            DatatypeConverter.theConverter = converter;
        }
        return;
    }
    
    private static synchronized void initConverter() {
        DatatypeConverter.theConverter = new DatatypeConverterImpl();
    }
    
    public static String parseString(String lexicalXSDString) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.parseString(lexicalXSDString);
    }
    
    public static BigInteger parseInteger(String lexicalXSDInteger) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.parseInteger(lexicalXSDInteger);
    }
    
    public static int parseInt(String lexicalXSDInt) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.parseInt(lexicalXSDInt);
    }
    
    public static long parseLong(String lexicalXSDLong) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.parseLong(lexicalXSDLong);
    }
    
    public static short parseShort(String lexicalXSDShort) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.parseShort(lexicalXSDShort);
    }
    
    public static BigDecimal parseDecimal(String lexicalXSDDecimal) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.parseDecimal(lexicalXSDDecimal);
    }
    
    public static float parseFloat(String lexicalXSDFloat) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.parseFloat(lexicalXSDFloat);
    }
    
    public static double parseDouble(String lexicalXSDDouble) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.parseDouble(lexicalXSDDouble);
    }
    
    public static boolean parseBoolean(String lexicalXSDBoolean) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.parseBoolean(lexicalXSDBoolean);
    }
    
    public static byte parseByte(String lexicalXSDByte) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.parseByte(lexicalXSDByte);
    }
    
    public static QName parseQName(String lexicalXSDQName, NamespaceContext nsc) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.parseQName(lexicalXSDQName, nsc);
    }
    
    public static Calendar parseDateTime(String lexicalXSDDateTime) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.parseDateTime(lexicalXSDDateTime);
    }
    
    public static byte[] parseBase64Binary(String lexicalXSDBase64Binary) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.parseBase64Binary(lexicalXSDBase64Binary);
    }
    
    public static byte[] parseHexBinary(String lexicalXSDHexBinary) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.parseHexBinary(lexicalXSDHexBinary);
    }
    
    public static long parseUnsignedInt(String lexicalXSDUnsignedInt) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.parseUnsignedInt(lexicalXSDUnsignedInt);
    }
    
    public static int parseUnsignedShort(String lexicalXSDUnsignedShort) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.parseUnsignedShort(lexicalXSDUnsignedShort);
    }
    
    public static Calendar parseTime(String lexicalXSDTime) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.parseTime(lexicalXSDTime);
    }
    
    public static Calendar parseDate(String lexicalXSDDate) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.parseDate(lexicalXSDDate);
    }
    
    public static String parseAnySimpleType(String lexicalXSDAnySimpleType) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.parseAnySimpleType(lexicalXSDAnySimpleType);
    }
    
    public static String printString(String val) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.printString(val);
    }
    
    public static String printInteger(BigInteger val) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.printInteger(val);
    }
    
    public static String printInt(int val) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.printInt(val);
    }
    
    public static String printLong(long val) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.printLong(val);
    }
    
    public static String printShort(short val) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.printShort(val);
    }
    
    public static String printDecimal(BigDecimal val) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.printDecimal(val);
    }
    
    public static String printFloat(float val) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.printFloat(val);
    }
    
    public static String printDouble(double val) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.printDouble(val);
    }
    
    public static String printBoolean(boolean val) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.printBoolean(val);
    }
    
    public static String printByte(byte val) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.printByte(val);
    }
    
    public static String printQName(QName val, NamespaceContext nsc) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.printQName(val, nsc);
    }
    
    public static String printDateTime(Calendar val) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.printDateTime(val);
    }
    
    public static String printBase64Binary(byte[] val) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.printBase64Binary(val);
    }
    
    public static String printHexBinary(byte[] val) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.printHexBinary(val);
    }
    
    public static String printUnsignedInt(long val) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.printUnsignedInt(val);
    }
    
    public static String printUnsignedShort(int val) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.printUnsignedShort(val);
    }
    
    public static String printTime(Calendar val) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.printTime(val);
    }
    
    public static String printDate(Calendar val) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.printDate(val);
    }
    
    public static String printAnySimpleType(String val) {
        if (DatatypeConverter.theConverter == null) {
            initConverter();
        }
        return DatatypeConverter.theConverter.printAnySimpleType(val);
    }
    
    static {
        DatatypeConverter.theConverter = null;
        SET_DATATYPE_CONVERTER_PERMISSION = new JAXBPermission("setDatatypeConverter");
    }
}
